/* Target-dependent code for Solaris.

   Copyright (C) 2006-2019 Free Software Foundation, Inc.

   This file is part of GDB.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#ifndef SOL2_TDEP_H
#define SOL2_TDEP_H 1

struct gdbarch;

CORE_ADDR sol2_skip_solib_resolver (struct gdbarch *, CORE_ADDR);

std::string sol2_core_pid_to_str (struct gdbarch *gdbarch, ptid_t ptid);

#endif /* sol2-tdep.h */
